@@ -19,7 +19,7 @@
 
 import os
 import re
-from typing import Iterator, Optional, List
+from typing import Iterator, Optional, List, Union
 
 from .reformatting import Editor
 
@@ -163,9 +163,10 @@ def _is_rule(line):
 
 
 class Makefile(object):
+    contents: List[Union[bytes, Rule]]
 
     def __init__(self, contents: Optional[bytes] = None):
-        self.contents = list(contents or [])
+        self.contents = list(contents or [])  # type: ignore
 
     @classmethod
     def from_path(cls, path: str) -> 'Makefile':
@@ -265,7 +266,7 @@ class Makefile(object):
     def dump(self):
         return b''.join(self.dump_lines())
 
-    def add_rule(self, target, components=None, precomment=None):
+    def add_rule(self, target, components=None, precomment=None) -> Rule:
         if self.contents:
             if isinstance(self.contents[-1], Rule):
                 self.contents.append(b'')
@@ -327,7 +328,8 @@ class RulesEditor(MakefileEditor):
         super(RulesEditor, self).__init__(path)
 
     def legacy_update(self, command_line_cb=None, global_line_cb=None,
-                      rule_cb=None, makefile_cb=None):
+                      rule_cb=None, makefile_cb=None,
+                      drop_related_comments=False):
         """Update a debian/rules file.
 
         Args:
@@ -374,7 +376,13 @@ class RulesEditor(MakefileEditor):
                 if global_line_cb:
                     line = global_line_cb(line)
                 if line is None:
-                    pass
+                    if drop_related_comments:
+                        while newcontents and newcontents[-1].startswith(b'#'):
+                            del newcontents[-1]
+                    if newcontents and not newcontents[-1]:
+                        del newcontents[-1]
+                    # TODO(jelmer): If there is no preceding whitespace, drop
+                    # next line if it's empty?
                 elif isinstance(line, list):
                     newcontents.extend(line)
                 elif isinstance(line, bytes):
@@ -420,7 +428,8 @@ def discard_pointless_override(makefile, rule, ignore_comments=False):
 
 def update_rules(command_line_cb=None, global_line_cb=None,
                  rule_cb=None,
-                 makefile_cb=None, path='debian/rules'):
+                 makefile_cb=None, path='debian/rules',
+                 drop_related_comments=False):
     """Update a debian/rules file.
 
     Args:
@@ -438,7 +447,8 @@ def update_rules(command_line_cb=None, global_line_cb=None,
             command_line_cb=command_line_cb,
             global_line_cb=global_line_cb,
             rule_cb=rule_cb,
-            makefile_cb=makefile_cb)
+            makefile_cb=makefile_cb,
+            drop_related_comments=drop_related_comments)
     return updater.changed
 
 
